@@ -26,18 +26,22 @@
  * </DESC>
  */
 #include <stdio.h>
+
 #include <curl/curl.h>
 
-#ifndef _WIN32
+#if !defined(_WIN32) && !defined(MSDOS) && !defined(__AMIGA__)
 #include <net/if.h>
 #endif
 
 int main(void)
 {
-#ifndef _WIN32
-  /* Windows users need to find how to use if_nametoindex() */
+#if !defined(_WIN32) && !defined(MSDOS) && !defined(__AMIGA__)
+  /* Windows/MS-DOS users need to find how to use if_nametoindex() */
   CURL *curl;
-  CURLcode res;
+
+  CURLcode result = curl_global_init(CURL_GLOBAL_ALL);
+  if(result)
+    return (int)result;
 
   curl = curl_easy_init();
   if(curl) {
@@ -47,16 +51,19 @@ int main(void)
     my_scope_id = (long)if_nametoindex("eth0");
     curl_easy_setopt(curl, CURLOPT_ADDRESS_SCOPE, my_scope_id);
 
-    /* Perform the request, res gets the return code */
-    res = curl_easy_perform(curl);
+    /* Perform the request, result gets the return code */
+    result = curl_easy_perform(curl);
     /* Check for errors */
-    if(res != CURLE_OK)
+    if(result != CURLE_OK)
       fprintf(stderr, "curl_easy_perform() failed: %s\n",
-              curl_easy_strerror(res));
+              curl_easy_strerror(result));
 
     /* always cleanup */
     curl_easy_cleanup(curl);
   }
-#endif
+  curl_global_cleanup();
+  return (int)result;
+#else
   return 0;
+#endif
 }
