@@ -25,9 +25,15 @@
  * Upload to FTP, resuming failed transfers. Active mode.
  * </DESC>
  */
+#ifdef _MSC_VER
+#ifndef _CRT_SECURE_NO_WARNINGS
+#define _CRT_SECURE_NO_WARNINGS  /* for fopen(), sscanf() */
+#endif
+#endif
 
 #include <stdlib.h>
 #include <stdio.h>
+
 #include <curl/curl.h>
 
 /* parse headers for Content-Length */
@@ -38,14 +44,14 @@ static size_t getcontentlengthfunc(void *ptr, size_t size, size_t nmemb,
   long len = 0;
 
   r = sscanf(ptr, "Content-Length: %ld\n", &len);
-  if(r)
-    *((long *) stream) = len;
+  if(r == 1)
+    *((long *)stream) = len;
 
   return size * nmemb;
 }
 
 /* discard downloaded data */
-static size_t discardfunc(void *ptr, size_t size, size_t nmemb, void *stream)
+static size_t write_cb(void *ptr, size_t size, size_t nmemb, void *stream)
 {
   (void)ptr;
   (void)stream;
@@ -53,7 +59,7 @@ static size_t discardfunc(void *ptr, size_t size, size_t nmemb, void *stream)
 }
 
 /* read data to upload */
-static size_t readfunc(char *ptr, size_t size, size_t nmemb, void *stream)
+static size_t read_cb(char *ptr, size_t size, size_t nmemb, void *stream)
 {
   FILE *f = stream;
   size_t n;
@@ -66,13 +72,12 @@ static size_t readfunc(char *ptr, size_t size, size_t nmemb, void *stream)
   return n;
 }
 
-
-static int upload(CURL *curlhandle, const char *remotepath,
+static int upload(CURL *curl, const char *remotepath,
                   const char *localpath, long timeout, long tries)
 {
   FILE *f;
   long uploaded_len = 0;
-  CURLcode r = CURLE_GOT_NOTHING;
+  CURLcode result = CURLE_GOT_NOTHING;
   int c;
 
   f = fopen(localpath, "rb");
@@ -81,32 +86,32 @@ static int upload(CURL *curlhandle, const char *remotepath,
     return 0;
   }
 
-  curl_easy_setopt(curlhandle, CURLOPT_UPLOAD, 1L);
+  curl_easy_setopt(curl, CURLOPT_UPLOAD, 1L);
 
-  curl_easy_setopt(curlhandle, CURLOPT_URL, remotepath);
+  curl_easy_setopt(curl, CURLOPT_URL, remotepath);
 
   if(timeout)
-    curl_easy_setopt(curlhandle, CURLOPT_SERVER_RESPONSE_TIMEOUT, timeout);
+    curl_easy_setopt(curl, CURLOPT_SERVER_RESPONSE_TIMEOUT, timeout);
 
-  curl_easy_setopt(curlhandle, CURLOPT_HEADERFUNCTION, getcontentlengthfunc);
-  curl_easy_setopt(curlhandle, CURLOPT_HEADERDATA, &uploaded_len);
+  curl_easy_setopt(curl, CURLOPT_HEADERFUNCTION, getcontentlengthfunc);
+  curl_easy_setopt(curl, CURLOPT_HEADERDATA, &uploaded_len);
 
-  curl_easy_setopt(curlhandle, CURLOPT_WRITEFUNCTION, discardfunc);
+  curl_easy_setopt(curl, CURLOPT_WRITEFUNCTION, write_cb);
 
-  curl_easy_setopt(curlhandle, CURLOPT_READFUNCTION, readfunc);
-  curl_easy_setopt(curlhandle, CURLOPT_READDATA, f);
+  curl_easy_setopt(curl, CURLOPT_READFUNCTION, read_cb);
+  curl_easy_setopt(curl, CURLOPT_READDATA, f);
 
   /* enable active mode */
-  curl_easy_setopt(curlhandle, CURLOPT_FTPPORT, "-");
+  curl_easy_setopt(curl, CURLOPT_FTPPORT, "-");
 
   /* allow the server no more than 7 seconds to connect back */
-  curl_easy_setopt(curlhandle, CURLOPT_ACCEPTTIMEOUT_MS, 7000L);
+  curl_easy_setopt(curl, CURLOPT_ACCEPTTIMEOUT_MS, 7000L);
 
-  curl_easy_setopt(curlhandle, CURLOPT_FTP_CREATE_MISSING_DIRS, 1L);
+  curl_easy_setopt(curl, CURLOPT_FTP_CREATE_MISSING_DIRS, 1L);
 
-  curl_easy_setopt(curlhandle, CURLOPT_VERBOSE, 1L);
+  curl_easy_setopt(curl, CURLOPT_VERBOSE, 1L);
 
-  for(c = 0; (r != CURLE_OK) && (c < tries); c++) {
+  for(c = 0; (result != CURLE_OK) && (c < tries); c++) {
     /* are we resuming? */
     if(c) { /* yes */
       /* determine the length of the file already written */
@@ -114,51 +119,53 @@ static int upload(CURL *curlhandle, const char *remotepath,
       /*
        * With NOBODY and NOHEADER, libcurl issues a SIZE command, but the only
        * way to retrieve the result is to parse the returned Content-Length
-       * header. Thus, getcontentlengthfunc(). We need discardfunc() above
+       * header. Thus, getcontentlengthfunc(). We need write_cb() above
        * because HEADER dumps the headers to stdout without it.
        */
-      curl_easy_setopt(curlhandle, CURLOPT_NOBODY, 1L);
-      curl_easy_setopt(curlhandle, CURLOPT_HEADER, 1L);
+      curl_easy_setopt(curl, CURLOPT_NOBODY, 1L);
+      curl_easy_setopt(curl, CURLOPT_HEADER, 1L);
 
-      r = curl_easy_perform(curlhandle);
-      if(r != CURLE_OK)
+      result = curl_easy_perform(curl);
+      if(result != CURLE_OK)
         continue;
 
-      curl_easy_setopt(curlhandle, CURLOPT_NOBODY, 0L);
-      curl_easy_setopt(curlhandle, CURLOPT_HEADER, 0L);
+      curl_easy_setopt(curl, CURLOPT_NOBODY, 0L);
+      curl_easy_setopt(curl, CURLOPT_HEADER, 0L);
 
       fseek(f, uploaded_len, SEEK_SET);
 
-      curl_easy_setopt(curlhandle, CURLOPT_APPEND, 1L);
+      curl_easy_setopt(curl, CURLOPT_APPEND, 1L);
     }
     else { /* no */
-      curl_easy_setopt(curlhandle, CURLOPT_APPEND, 0L);
+      curl_easy_setopt(curl, CURLOPT_APPEND, 0L);
     }
 
-    r = curl_easy_perform(curlhandle);
+    result = curl_easy_perform(curl);
   }
 
   fclose(f);
 
-  if(r == CURLE_OK)
+  if(result == CURLE_OK)
     return 1;
   else {
-    fprintf(stderr, "%s\n", curl_easy_strerror(r));
+    fprintf(stderr, "%s\n", curl_easy_strerror(result));
     return 0;
   }
 }
 
 int main(void)
 {
-  CURL *curlhandle = NULL;
+  CURL *curl = NULL;
 
-  curl_global_init(CURL_GLOBAL_ALL);
-  curlhandle = curl_easy_init();
+  CURLcode result = curl_global_init(CURL_GLOBAL_ALL);
+  if(result)
+    return (int)result;
 
-  upload(curlhandle, "ftp://user:pass@example.com/path/file", "C:\\file",
-         0, 3);
-
-  curl_easy_cleanup(curlhandle);
+  curl = curl_easy_init();
+  if(curl) {
+    upload(curl, "ftp://user:pass@example.com/path/file", "C:\\file", 0, 3);
+    curl_easy_cleanup(curl);
+  }
   curl_global_cleanup();
 
   return 0;
