@@ -28,14 +28,15 @@
 /*
  * LibTidy => https://www.html-tidy.org/
  */
-
 #include <stdio.h>
+
 #include <tidy/tidy.h>
 #include <tidy/tidybuffio.h>
+
 #include <curl/curl.h>
 
 /* curl write callback, to fill tidy's input buffer...  */
-uint write_cb(char *in, uint size, uint nmemb, TidyBuffer *out)
+static uint write_cb(char *in, uint size, uint nmemb, TidyBuffer *out)
 {
   uint r;
   r = size * nmemb;
@@ -44,17 +45,17 @@ uint write_cb(char *in, uint size, uint nmemb, TidyBuffer *out)
 }
 
 /* Traverse the document tree */
-void dumpNode(TidyDoc doc, TidyNode tnod, int indent)
+static void dumpNode(TidyDoc doc, TidyNode tnod, int indent)
 {
   TidyNode child;
-  for(child = tidyGetChild(tnod); child; child = tidyGetNext(child) ) {
+  for(child = tidyGetChild(tnod); child; child = tidyGetNext(child)) {
     ctmbstr name = tidyNodeGetName(child);
     if(name) {
-      /* if it has a name, then it's an HTML tag ... */
+      /* if it has a name, then it is an HTML tag ... */
       TidyAttr attr;
       printf("%*.*s%s ", indent, indent, "<", name);
       /* walk the attribute list */
-      for(attr = tidyAttrFirst(child); attr; attr = tidyAttrNext(attr) ) {
+      for(attr = tidyAttrFirst(child); attr; attr = tidyAttrNext(attr)) {
         printf("%s", tidyAttrName(attr));
         tidyAttrValue(attr) ? printf("=\"%s\" ",
                                      tidyAttrValue(attr)) : printf(" ");
@@ -62,7 +63,7 @@ void dumpNode(TidyDoc doc, TidyNode tnod, int indent)
       printf(">\n");
     }
     else {
-      /* if it does not have a name, then it's probably text, cdata, etc... */
+      /* if it does not have a name, then it is probably text, cdata, etc... */
       TidyBuffer buf;
       tidyBufInit(&buf);
       tidyNodeGetText(doc, child, &buf);
@@ -73,31 +74,23 @@ void dumpNode(TidyDoc doc, TidyNode tnod, int indent)
   }
 }
 
-
 int main(int argc, char **argv)
 {
   CURL *curl;
   char curl_errbuf[CURL_ERROR_SIZE];
   TidyDoc tdoc;
-  TidyBuffer docbuf = {0};
-  TidyBuffer tidy_errbuf = {0};
-  CURLcode res;
+  TidyBuffer docbuf = { 0 };
+  TidyBuffer tidy_errbuf = { 0 };
+  CURLcode result;
 
   if(argc != 2) {
     printf("usage: %s <url>\n", argv[0]);
     return 1;
   }
 
-  res = curl_global_init(CURL_GLOBAL_ALL);
-  if(res)
-    return (int)res;
-
-  curl = curl_easy_init();
-  curl_easy_setopt(curl, CURLOPT_URL, argv[1]);
-  curl_easy_setopt(curl, CURLOPT_ERRORBUFFER, curl_errbuf);
-  curl_easy_setopt(curl, CURLOPT_NOPROGRESS, 0L);
-  curl_easy_setopt(curl, CURLOPT_VERBOSE, 1L);
-  curl_easy_setopt(curl, CURLOPT_WRITEFUNCTION, write_cb);
+  result = curl_global_init(CURL_GLOBAL_ALL);
+  if(result)
+    return (int)result;
 
   tdoc = tidyCreate();
   tidyOptSetBool(tdoc, TidyForceOutput, yes); /* try harder */
@@ -105,29 +98,41 @@ int main(int argc, char **argv)
   tidySetErrorBuffer(tdoc, &tidy_errbuf);
   tidyBufInit(&docbuf);
 
-  curl_easy_setopt(curl, CURLOPT_WRITEDATA, &docbuf);
-  res = curl_easy_perform(curl);
-  if(!res) {
-    res = tidyParseBuffer(tdoc, &docbuf); /* parse the input */
-    if(res >= 0) {
-      res = tidyCleanAndRepair(tdoc); /* fix any problems */
-      if(res >= 0) {
-        res = tidyRunDiagnostics(tdoc); /* load tidy error buffer */
-        if(res >= 0) {
-          dumpNode(tdoc, tidyGetRoot(tdoc), 0); /* walk the tree */
-          fprintf(stderr, "%s\n", tidy_errbuf.bp); /* show errors */
+  curl = curl_easy_init();
+  if(curl) {
+    curl_easy_setopt(curl, CURLOPT_URL, argv[1]);
+    curl_easy_setopt(curl, CURLOPT_ERRORBUFFER, curl_errbuf);
+    curl_easy_setopt(curl, CURLOPT_NOPROGRESS, 0L);
+    curl_easy_setopt(curl, CURLOPT_VERBOSE, 1L);
+    curl_easy_setopt(curl, CURLOPT_WRITEFUNCTION, write_cb);
+
+    curl_easy_setopt(curl, CURLOPT_WRITEDATA, &docbuf);
+    result = curl_easy_perform(curl);
+    if(!result) {
+      result = tidyParseBuffer(tdoc, &docbuf); /* parse the input */
+      if(result >= 0) {
+        result = tidyCleanAndRepair(tdoc); /* fix any problems */
+        if(result >= 0) {
+          result = tidyRunDiagnostics(tdoc); /* load tidy error buffer */
+          if(result >= 0) {
+            dumpNode(tdoc, tidyGetRoot(tdoc), 0); /* walk the tree */
+            fprintf(stderr, "%s\n", tidy_errbuf.bp); /* show errors */
+          }
         }
       }
     }
+    else
+      fprintf(stderr, "%s\n", curl_errbuf);
+
+    /* clean-up */
+    curl_easy_cleanup(curl);
   }
-  else
-    fprintf(stderr, "%s\n", curl_errbuf);
 
-  /* clean-up */
-  curl_easy_cleanup(curl);
-  curl_global_cleanup();
   tidyBufFree(&docbuf);
   tidyBufFree(&tidy_errbuf);
   tidyRelease(tdoc);
-  return (int)res;
+
+  curl_global_cleanup();
+
+  return (int)result;
 }
