@@ -25,16 +25,14 @@
  * multi interface and debug callback
  * </DESC>
  */
-
 #include <stdio.h>
 #include <string.h>
 
-/* curl stuff */
 #include <curl/curl.h>
 
 #define TRUE 1
 
-static void dump(const char *text, FILE *stream, unsigned char *ptr,
+static void dump(const char *text, FILE *stream, const unsigned char *ptr,
                  size_t size, char nohex)
 {
   size_t i;
@@ -71,7 +69,7 @@ static void dump(const char *text, FILE *stream, unsigned char *ptr,
       }
       fprintf(stream, "%c",
               (ptr[i + c] >= 0x20) && (ptr[i + c] < 0x80) ? ptr[i + c] : '.');
-      /* check again for 0D0A, to avoid an extra \n if it's at width */
+      /* check again for 0D0A, to avoid an extra \n if it is at width */
       if(nohex && (i + c + 2 < size) && ptr[i + c + 1] == 0x0D &&
          ptr[i + c + 2] == 0x0A) {
         i += (c + 3 - width);
@@ -83,15 +81,14 @@ static void dump(const char *text, FILE *stream, unsigned char *ptr,
   fflush(stream);
 }
 
-static
-int my_trace(CURL *handle, curl_infotype type,
-             unsigned char *data, size_t size,
-             void *userp)
+static int my_trace(CURL *curl, curl_infotype type,
+                    unsigned char *data, size_t size,
+                    void *userp)
 {
   const char *text;
 
   (void)userp;
-  (void)handle;
+  (void)curl;
 
   switch(type) {
   case CURLINFO_TEXT:
@@ -122,44 +119,49 @@ int my_trace(CURL *handle, curl_infotype type,
  */
 int main(void)
 {
-  CURL *http_handle;
-  CURLM *multi_handle;
+  CURL *curl;
 
-  int still_running = 0; /* keep number of running handles */
+  CURLcode result = curl_global_init(CURL_GLOBAL_ALL);
+  if(result)
+    return (int)result;
 
-  CURLcode res = curl_global_init(CURL_GLOBAL_ALL);
-  if(res)
-    return (int)res;
+  curl = curl_easy_init();
+  if(curl) {
 
-  http_handle = curl_easy_init();
+    CURLM *multi;
 
-  /* set the options (I left out a few, you get the point anyway) */
-  curl_easy_setopt(http_handle, CURLOPT_URL, "https://www.example.com/");
+    /* set the options (I left out a few, you get the point anyway) */
+    curl_easy_setopt(curl, CURLOPT_URL, "https://www.example.com/");
 
-  curl_easy_setopt(http_handle, CURLOPT_DEBUGFUNCTION, my_trace);
-  curl_easy_setopt(http_handle, CURLOPT_VERBOSE, 1L);
+    curl_easy_setopt(curl, CURLOPT_DEBUGFUNCTION, my_trace);
+    curl_easy_setopt(curl, CURLOPT_VERBOSE, 1L);
 
-  /* init a multi stack */
-  multi_handle = curl_multi_init();
+    /* init a multi stack */
+    multi = curl_multi_init();
+    if(multi) {
 
-  /* add the individual transfers */
-  curl_multi_add_handle(multi_handle, http_handle);
+      int still_running = 0; /* keep number of running handles */
 
-  do {
-    CURLMcode mc = curl_multi_perform(multi_handle, &still_running);
+      /* add the individual transfers */
+      curl_multi_add_handle(multi, curl);
 
-    if(still_running)
-      /* wait for activity, timeout or "nothing" */
-      mc = curl_multi_poll(multi_handle, NULL, 0, 1000, NULL);
+      do {
+        CURLMcode mresult = curl_multi_perform(multi, &still_running);
 
-    if(mc)
-      break;
+        if(still_running)
+          /* wait for activity, timeout or "nothing" */
+          mresult = curl_multi_poll(multi, NULL, 0, 1000, NULL);
 
-  } while(still_running);
+        if(mresult)
+          break;
 
-  curl_multi_cleanup(multi_handle);
+      } while(still_running);
 
-  curl_easy_cleanup(http_handle);
+      curl_multi_cleanup(multi);
+    }
+
+    curl_easy_cleanup(curl);
+  }
 
   curl_global_cleanup();
 
