@@ -23,46 +23,39 @@
  * SPDX-License-Identifier: curl
  *
  ***************************************************************************/
-
 #include "curl_setup.h"
 
-#include <stddef.h>
-
-#include "llist.h"
-
-/* A version with unsigned int as key */
-typedef void Curl_uint_hash_dtor(unsigned int id, void *value);
+/* A version with uint32_t as key */
+typedef void Curl_uint32_hash_dtor(uint32_t id, void *value);
 struct uint_hash_entry;
 
-/* Hash for `unsigned int` as key */
+/* Hash for `uint32_t` as key */
 struct uint_hash {
   struct uint_hash_entry **table;
-  Curl_uint_hash_dtor *dtor;
-  unsigned int slots;
-  unsigned int size;
+  Curl_uint32_hash_dtor *dtor;
+  uint32_t slots;
+  uint32_t size;
 #ifdef DEBUGBUILD
   int init;
 #endif
 };
 
+void Curl_uint32_hash_init(struct uint_hash *h,
+                           uint32_t slots,
+                           Curl_uint32_hash_dtor *dtor);
+void Curl_uint32_hash_destroy(struct uint_hash *h);
+void Curl_uint32_hash_clear(struct uint_hash *h);
 
-void Curl_uint_hash_init(struct uint_hash *h,
-                         unsigned int slots,
-                         Curl_uint_hash_dtor *dtor);
-void Curl_uint_hash_destroy(struct uint_hash *h);
-void Curl_uint_hash_clear(struct uint_hash *h);
+bool Curl_uint32_hash_set(struct uint_hash *h, uint32_t id, void *value);
+bool Curl_uint32_hash_remove(struct uint_hash *h, uint32_t id);
+void *Curl_uint32_hash_get(struct uint_hash *h, uint32_t id);
+uint32_t Curl_uint32_hash_count(struct uint_hash *h);
 
-bool Curl_uint_hash_set(struct uint_hash *h, unsigned int id, void *value);
-bool Curl_uint_hash_remove(struct uint_hash *h, unsigned int id);
-void *Curl_uint_hash_get(struct uint_hash *h, unsigned int id);
-unsigned int Curl_uint_hash_count(struct uint_hash *h);
+typedef bool Curl_uint32_hash_visit_cb(uint32_t id, void *value,
+                                       void *user_data);
 
-
-typedef bool Curl_uint_hash_visit_cb(unsigned int id, void *value,
-                                     void *user_data);
-
-void Curl_uint_hash_visit(struct uint_hash *h,
-                          Curl_uint_hash_visit_cb *cb,
-                          void *user_data);
+void Curl_uint32_hash_visit(struct uint_hash *h,
+                            Curl_uint32_hash_visit_cb *cb,
+                            void *user_data);
 
 #endif /* HEADER_CURL_UINT_HASH_H */
