@@ -22,20 +22,20 @@
  *
  ***************************************************************************/
 #include "tool_setup.h"
+
 #include "tool_operate.h"
 #include "tool_progress.h"
-#include "tool_util.h"
 
 /* The point of this function would be to return a string of the input data,
    but never longer than 5 columns (+ one zero byte).
    Add suffix k, M, G when suitable... */
-static char *max5data(curl_off_t bytes, char *max5)
+UNITTEST char *max5data(curl_off_t bytes, char *max5, size_t mlen)
 {
   /* a signed 64-bit value is 8192 petabytes maximum */
-  const char unit[] = { 'k', 'M', 'G', 'T', 'P', 0 };
+  const char unit[] = { 'k', 'M', 'G', 'T', 'P', 'E', 0 };
   int k = 0;
   if(bytes < 100000) {
-    msnprintf(max5, 6, "%5" CURL_FORMAT_CURL_OFF_T, bytes);
+    curl_msnprintf(max5, mlen, "%5" CURL_FORMAT_CURL_OFF_T, bytes);
     return max5;
   }
 
@@ -43,14 +43,15 @@ static char *max5data(curl_off_t bytes, char *max5)
     curl_off_t nbytes = bytes / 1024;
     if(nbytes < 100) {
       /* display with a decimal */
-      msnprintf(max5, 6, "%2" CURL_FORMAT_CURL_OFF_T ".%0"
-                CURL_FORMAT_CURL_OFF_T "%c", bytes/1024,
-                (bytes%1024) / (1024/10), unit[k]);
+      curl_msnprintf(max5, mlen, "%2" CURL_FORMAT_CURL_OFF_T ".%"
+                     CURL_FORMAT_CURL_OFF_T "%c", bytes / 1024,
+                     (bytes % 1024) * 10 / 1024, unit[k]);
       break;
     }
     else if(nbytes < 10000) {
       /* no decimals */
-      msnprintf(max5, 6, "%4" CURL_FORMAT_CURL_OFF_T "%c", nbytes, unit[k]);
+      curl_msnprintf(max5, mlen, "%4" CURL_FORMAT_CURL_OFF_T "%c", nbytes,
+                     unit[k]);
       break;
     }
     bytes = nbytes;
@@ -84,32 +85,39 @@ int xferinfo_cb(void *clientp,
   return 0;
 }
 
-/* Provide a string that is 2 + 1 + 2 + 1 + 2 = 8 letters long (plus the zero
-   byte) */
-static void time2str(char *r, curl_off_t seconds)
+/* Provide a time string that is 8 letters long (plus the zero byte) */
+UNITTEST void time2str(char *r, size_t rlen, curl_off_t seconds)
 {
   curl_off_t h;
   if(seconds <= 0) {
-    strcpy(r, "--:--:--");
+    curlx_strcopy(r, rlen, "        ", 8);
     return;
   }
   h = seconds / 3600;
   if(h <= 99) {
     curl_off_t m = (seconds - (h * 3600)) / 60;
     curl_off_t s = (seconds - (h * 3600)) - (m * 60);
-    msnprintf(r, 9, "%2" CURL_FORMAT_CURL_OFF_T ":%02" CURL_FORMAT_CURL_OFF_T
-              ":%02" CURL_FORMAT_CURL_OFF_T, h, m, s);
+    curl_msnprintf(r, rlen, "%02" FMT_OFF_T ":%02" FMT_OFF_T ":"
+                   "%02" FMT_OFF_T, h, m, s);
   }
   else {
-    /* this equals to more than 99 hours, switch to a more suitable output
-       format to fit within the limits. */
     curl_off_t d = seconds / 86400;
     h = (seconds - (d * 86400)) / 3600;
     if(d <= 999)
-      msnprintf(r, 9, "%3" CURL_FORMAT_CURL_OFF_T
-                "d %02" CURL_FORMAT_CURL_OFF_T "h", d, h);
-    else
-      msnprintf(r, 9, "%7" CURL_FORMAT_CURL_OFF_T "d", d);
+      curl_msnprintf(r, rlen, "%3" FMT_OFF_T "d %02" FMT_OFF_T "h", d, h);
+    else { /* more than 999 days */
+      curl_off_t m = d / 30;
+      if(m <= 999) {
+        curl_msnprintf(r, rlen, "%3" FMT_OFF_T "m %02" FMT_OFF_T "d", m, d%30);
+      }
+      else { /* more than 999 months */
+        curl_off_t y = d / 365;
+        if(y <= 99999)
+          curl_msnprintf(r, rlen, "%7" FMT_OFF_T "y", y);
+        else
+          curlx_strcopy(r, rlen, " >99999y", 8);
+      }
+    }
   }
 }
 
@@ -141,9 +149,7 @@ static void add_offt(curl_off_t *val, curl_off_t add)
   |DL% UL%  Dled  Uled  Xfers  Live Total     Current  Left    Speed
   |  6 --   9.9G     0     2     2   0:00:40  0:00:02  0:00:37 4087M
 */
-bool progress_meter(CURLM *multi,
-                    struct curltime *start,
-                    bool final)
+bool progress_meter(CURLM *multi, struct curltime *start, bool final)
 {
   static struct curltime stamp;
   static bool header = FALSE;
@@ -154,7 +160,7 @@ bool progress_meter(CURLM *multi,
     return FALSE;
 
   now = curlx_now();
-  diff = curlx_timediff(now, stamp);
+  diff = curlx_timediff_ms(now, stamp);
 
   if(!header) {
     header = TRUE;
@@ -163,13 +169,13 @@ bool progress_meter(CURLM *multi,
           tool_stderr);
   }
   if(final || (diff > 500)) {
-    char time_left[10];
-    char time_total[10];
-    char time_spent[10];
+    char time_left[9];
+    char time_total[9];
+    char time_spent[9];
     char buffer[3][6];
-    curl_off_t spent = curlx_timediff(now, *start)/1000;
-    char dlpercen[4]="--";
-    char ulpercen[4]="--";
+    curl_off_t spent = curlx_timediff_ms(now, *start) / 1000;
+    char dlpercen[4] = "--";
+    char ulpercen[4] = "--";
     struct per_transfer *per;
     curl_off_t all_dlnow = 0;
     curl_off_t all_ulnow = 0;
@@ -204,16 +210,16 @@ bool progress_meter(CURLM *multi,
       }
     }
     if(dlknown && all_dltotal)
-      msnprintf(dlpercen, sizeof(dlpercen), "%3" CURL_FORMAT_CURL_OFF_T,
-                all_dlnow < (CURL_OFF_T_MAX/100) ?
-                (all_dlnow * 100 / all_dltotal) :
-                (all_dlnow / (all_dltotal/100)));
+      curl_msnprintf(dlpercen, sizeof(dlpercen), "%3" CURL_FORMAT_CURL_OFF_T,
+                     all_dlnow < (CURL_OFF_T_MAX / 100) ?
+                     (all_dlnow * 100 / all_dltotal) :
+                     (all_dlnow / (all_dltotal / 100)));
 
     if(ulknown && all_ultotal)
-      msnprintf(ulpercen, sizeof(ulpercen), "%3" CURL_FORMAT_CURL_OFF_T,
-                all_ulnow < (CURL_OFF_T_MAX/100) ?
-                (all_ulnow * 100 / all_ultotal) :
-                (all_ulnow / (all_ultotal/100)));
+      curl_msnprintf(ulpercen, sizeof(ulpercen), "%3" CURL_FORMAT_CURL_OFF_T,
+                     all_ulnow < (CURL_OFF_T_MAX / 100) ?
+                     (all_ulnow * 100 / all_ultotal) :
+                     (all_ulnow / (all_ultotal / 100)));
 
     /* get the transfer speed, the higher of the two */
 
@@ -234,63 +240,62 @@ bool progress_meter(CURLM *multi,
       curl_off_t uls;
       if(indexwrapped) {
         /* 'speedindex' is the oldest stored data */
-        deltams = curlx_timediff(now, speedstore[speedindex].stamp);
+        deltams = curlx_timediff_ms(now, speedstore[speedindex].stamp);
         dl = all_dlnow - speedstore[speedindex].dl;
         ul = all_ulnow - speedstore[speedindex].ul;
       }
       else {
         /* since the beginning */
-        deltams = curlx_timediff(now, *start);
+        deltams = curlx_timediff_ms(now, *start);
         dl = all_dlnow;
         ul = all_ulnow;
       }
       if(!deltams) /* no division by zero please */
         deltams++;
-      dls = (curl_off_t)((double)dl / ((double)deltams/1000.0));
-      uls = (curl_off_t)((double)ul / ((double)deltams/1000.0));
+      dls = (curl_off_t)((double)dl / ((double)deltams / 1000.0));
+      uls = (curl_off_t)((double)ul / ((double)deltams / 1000.0));
       speed = dls > uls ? dls : uls;
     }
 
-
     if(dlknown && speed) {
       curl_off_t est = all_dltotal / speed;
       curl_off_t left = (all_dltotal - all_dlnow) / speed;
-      time2str(time_left, left);
-      time2str(time_total, est);
+      time2str(time_left, sizeof(time_left), left);
+      time2str(time_total, sizeof(time_total), est);
     }
     else {
-      time2str(time_left, 0);
-      time2str(time_total, 0);
+      time2str(time_left, sizeof(time_left), 0);
+      time2str(time_total, sizeof(time_total), 0);
     }
-    time2str(time_spent, spent);
+    time2str(time_spent, sizeof(time_spent), spent);
 
     (void)curl_multi_get_offt(multi, CURLMINFO_XFERS_ADDED, &xfers_added);
     (void)curl_multi_get_offt(multi, CURLMINFO_XFERS_RUNNING, &xfers_running);
-    fprintf(tool_stderr,
-            "\r"
-            "%-3s " /* percent downloaded */
-            "%-3s " /* percent uploaded */
-            "%s " /* Dled */
-            "%s " /* Uled */
-            "%5" CURL_FORMAT_CURL_OFF_T " " /* Xfers */
-            "%5" CURL_FORMAT_CURL_OFF_T " " /* Live */
-            " %s "  /* Total time */
-            "%s "  /* Current time */
-            "%s "  /* Time left */
-            "%s "  /* Speed */
-            "%5s" /* final newline */,
+    curl_mfprintf(tool_stderr,
+                  "\r"
+                  "%-3s " /* percent downloaded */
+                  "%-3s " /* percent uploaded */
+                  "%s " /* Dled */
+                  "%s " /* Uled */
+                  "%5" CURL_FORMAT_CURL_OFF_T " " /* Xfers */
+                  "%5" CURL_FORMAT_CURL_OFF_T " " /* Live */
+                  " %s "  /* Total time */
+                  "%s "  /* Current time */
+                  "%s "  /* Time left */
+                  "%s "  /* Speed */
+                  "%5s" /* final newline */,
 
-            dlpercen,  /* 3 letters */
-            ulpercen,  /* 3 letters */
-            max5data(all_dlnow, buffer[0]),
-            max5data(all_ulnow, buffer[1]),
-            xfers_added,
-            xfers_running,
-            time_total,
-            time_spent,
-            time_left,
-            max5data(speed, buffer[2]), /* speed */
-            final ? "\n" :"");
+                  dlpercen,  /* 3 letters */
+                  ulpercen,  /* 3 letters */
+                  max5data(all_dlnow, buffer[0], sizeof(buffer[0])),
+                  max5data(all_ulnow, buffer[1], sizeof(buffer[1])),
+                  xfers_added,
+                  xfers_running,
+                  time_total,
+                  time_spent,
+                  time_left,
+                  max5data(speed, buffer[2], sizeof(buffer[2])), /* speed */
+                  final ? "\n" : "");
     return TRUE;
   }
   return FALSE;
