@@ -23,10 +23,8 @@
  ***************************************************************************/
 #include "first.h"
 
-#include "memdebug.h"
-
 struct t1485_transfer_status {
-  CURL *easy;
+  CURL *curl;
   curl_off_t out_len;
   size_t hd_line;
   CURLcode result;
@@ -47,7 +45,7 @@ static size_t t1485_header_callback(char *ptr, size_t size, size_t nmemb,
     curl_off_t clen;
     long httpcode = 0;
     /* end of a response */
-    result = curl_easy_getinfo(st->easy, CURLINFO_RESPONSE_CODE, &httpcode);
+    result = curl_easy_getinfo(st->curl, CURLINFO_RESPONSE_CODE, &httpcode);
     curl_mfprintf(stderr, "header_callback, get status: %ld, %d\n",
                   httpcode, result);
     if(httpcode < 100 || httpcode >= 1000) {
@@ -57,10 +55,10 @@ static size_t t1485_header_callback(char *ptr, size_t size, size_t nmemb,
     }
     st->http_status = (int)httpcode;
     if(st->http_status >= 200 && st->http_status < 300) {
-      result = curl_easy_getinfo(st->easy, CURLINFO_CONTENT_LENGTH_DOWNLOAD_T,
-                                 &clen);
-      curl_mfprintf(stderr, "header_callback, info Content-Length: %ld, %d\n",
-                    (long)clen, result);
+      result = curl_easy_getinfo(st->curl, CURLINFO_CONTENT_LENGTH_DOWNLOAD_T,
+                              &clen);
+      curl_mfprintf(stderr, "header_callback, info Content-Length: "
+                    "%" CURL_FORMAT_CURL_OFF_T ", %d\n", clen, result);
       if(result) {
         st->result = result;
         return CURLE_WRITE_ERROR;
@@ -68,7 +66,7 @@ static size_t t1485_header_callback(char *ptr, size_t size, size_t nmemb,
       if(clen < 0) {
         curl_mfprintf(stderr,
                       "header_callback, expected known Content-Length, "
-                      "got: %ld\n", (long)clen);
+                      "got: %" CURL_FORMAT_CURL_OFF_T "\n", clen);
         return CURLE_WRITE_ERROR;
       }
     }
@@ -85,10 +83,10 @@ static size_t t1485_write_cb(char *ptr, size_t size, size_t nmemb, void *userp)
   return len;
 }
 
-static CURLcode test_lib1485(char *URL)
+static CURLcode test_lib1485(const char *URL)
 {
-  CURL *curls = NULL;
-  CURLcode res = CURLE_OK;
+  CURL *curl = NULL;
+  CURLcode result = CURLE_OK;
   struct t1485_transfer_status st;
 
   start_test_timing();
@@ -97,23 +95,23 @@ static CURLcode test_lib1485(char *URL)
 
   global_init(CURL_GLOBAL_ALL);
 
-  easy_init(curls);
-  st.easy = curls; /* to allow callbacks access */
+  easy_init(curl);
+  st.curl = curl; /* to allow callbacks access */
 
-  easy_setopt(curls, CURLOPT_URL, URL);
-  easy_setopt(curls, CURLOPT_WRITEFUNCTION, t1485_write_cb);
-  easy_setopt(curls, CURLOPT_WRITEDATA, &st);
-  easy_setopt(curls, CURLOPT_HEADERFUNCTION, t1485_header_callback);
-  easy_setopt(curls, CURLOPT_HEADERDATA, &st);
+  easy_setopt(curl, CURLOPT_URL, URL);
+  easy_setopt(curl, CURLOPT_WRITEFUNCTION, t1485_write_cb);
+  easy_setopt(curl, CURLOPT_WRITEDATA, &st);
+  easy_setopt(curl, CURLOPT_HEADERFUNCTION, t1485_header_callback);
+  easy_setopt(curl, CURLOPT_HEADERDATA, &st);
 
-  easy_setopt(curls, CURLOPT_NOPROGRESS, 1L);
+  easy_setopt(curl, CURLOPT_NOPROGRESS, 1L);
 
-  res = curl_easy_perform(curls);
+  result = curl_easy_perform(curl);
 
 test_cleanup:
 
-  curl_easy_cleanup(curls);
+  curl_easy_cleanup(curl);
   curl_global_cleanup();
 
-  return res; /* return the final return code */
+  return result; /* return the final return code */
 }
