@@ -23,16 +23,6 @@
  ***************************************************************************/
 #include "first.h"
 
-#include "memdebug.h"
-
-/*
- * This is the list of basic details you need to tweak to get things right.
- */
-#define USERNAME "user@example.com"
-#define PASSWORD "123qwerty"
-#define RECIPIENT "<1507-recipient@example.com>"
-#define MAILFROM "<1507-realuser@example.com>"
-
 static size_t t1507_read_cb(char *ptr, size_t size, size_t nmemb, void *userp)
 {
   (void)ptr;
@@ -42,44 +32,44 @@ static size_t t1507_read_cb(char *ptr, size_t size, size_t nmemb, void *userp)
   return CURL_READFUNC_ABORT;
 }
 
-static CURLcode test_lib1507(char *URL)
+static CURLcode test_lib1507(const char *URL)
 {
-   static const int MULTI_PERFORM_HANG_TIMEOUT = 60 * 1000;
+  static const int MULTI_PERFORM_HANG_TIMEOUT = 60 * 1000;
 
-   CURLcode res = CURLE_OK;
-   CURL *curl = NULL;
-   CURLM *mcurl = NULL;
-   int still_running = 1;
-   struct curltime mp_start;
-   struct curl_slist *rcpt_list = NULL;
+  CURLcode result = CURLE_OK;
+  CURL *curl = NULL;
+  CURLM *multi = NULL;
+  int still_running = 1;
+  struct curltime mp_start;
+  struct curl_slist *rcpt_list = NULL;
 
-   curl_global_init(CURL_GLOBAL_DEFAULT);
+  curl_global_init(CURL_GLOBAL_DEFAULT);
 
-   easy_init(curl);
+  easy_init(curl);
 
-   multi_init(mcurl);
+  multi_init(multi);
 
-   rcpt_list = curl_slist_append(rcpt_list, RECIPIENT);
-   /* more addresses can be added here
-      rcpt_list = curl_slist_append(rcpt_list, "<others@example.com>");
-   */
-
-   curl_easy_setopt(curl, CURLOPT_URL, URL);
+  rcpt_list = curl_slist_append(rcpt_list, "<1507-recipient@example.com>");
 #if 0
-   curl_easy_setopt(curl, CURLOPT_USERNAME, USERNAME);
-   curl_easy_setopt(curl, CURLOPT_PASSWORD, PASSWORD);
+  /* more addresses can be added here */
+  rcpt_list = curl_slist_append(rcpt_list, "<others@example.com>");
 #endif
-   curl_easy_setopt(curl, CURLOPT_UPLOAD, 1L);
-   curl_easy_setopt(curl, CURLOPT_READFUNCTION, t1507_read_cb);
-   curl_easy_setopt(curl, CURLOPT_MAIL_FROM, MAILFROM);
-   curl_easy_setopt(curl, CURLOPT_MAIL_RCPT, rcpt_list);
-   curl_easy_setopt(curl, CURLOPT_VERBOSE, 1L);
-   multi_add_handle(mcurl, curl);
+  curl_easy_setopt(curl, CURLOPT_URL, URL);
+#if 0
+  curl_easy_setopt(curl, CURLOPT_USERNAME, "user@example.com");
+  curl_easy_setopt(curl, CURLOPT_PASSWORD, "123qwerty");
+#endif
+  curl_easy_setopt(curl, CURLOPT_UPLOAD, 1L);
+  curl_easy_setopt(curl, CURLOPT_READFUNCTION, t1507_read_cb);
+  curl_easy_setopt(curl, CURLOPT_MAIL_FROM, "<1507-realuser@example.com>");
+  curl_easy_setopt(curl, CURLOPT_MAIL_RCPT, rcpt_list);
+  curl_easy_setopt(curl, CURLOPT_VERBOSE, 1L);
+  multi_add_handle(multi, curl);
 
-   mp_start = curlx_now();
+  mp_start = curlx_now();
 
   /* we start some action by calling perform right away */
-  curl_multi_perform(mcurl, &still_running);
+  curl_multi_perform(multi, &still_running);
 
   while(still_running) {
     struct timeval timeout;
@@ -100,7 +90,7 @@ static CURLcode test_lib1507(char *URL)
     timeout.tv_sec = 1;
     timeout.tv_usec = 0;
 
-    curl_multi_timeout(mcurl, &curl_timeo);
+    curl_multi_timeout(multi, &curl_timeo);
     if(curl_timeo >= 0) {
       curlx_mstotv(&timeout, curl_timeo);
       if(timeout.tv_sec > 1) {
@@ -110,7 +100,7 @@ static CURLcode test_lib1507(char *URL)
     }
 
     /* get file descriptors from the transfers */
-    curl_multi_fdset(mcurl, &fdread, &fdwrite, &fdexcep, &maxfd);
+    curl_multi_fdset(multi, &fdread, &fdwrite, &fdexcep, &maxfd);
 
     /* In a real-world program you OF COURSE check the return code of the
        function calls.  On success, the value of maxfd is guaranteed to be
@@ -120,7 +110,7 @@ static CURLcode test_lib1507(char *URL)
 
     rc = select(maxfd + 1, &fdread, &fdwrite, &fdexcep, &timeout);
 
-    if(curlx_timediff(curlx_now(), mp_start) > MULTI_PERFORM_HANG_TIMEOUT) {
+    if(curlx_timediff_ms(curlx_now(), mp_start) > MULTI_PERFORM_HANG_TIMEOUT) {
       curl_mfprintf(stderr, "ABORTING TEST, since it seems "
                     "that it would have run forever.\n");
       break;
@@ -132,7 +122,7 @@ static CURLcode test_lib1507(char *URL)
       break;
     case 0: /* timeout */
     default: /* action */
-      curl_multi_perform(mcurl, &still_running);
+      curl_multi_perform(multi, &still_running);
       break;
     }
   }
@@ -140,10 +130,10 @@ static CURLcode test_lib1507(char *URL)
 test_cleanup:
 
   curl_slist_free_all(rcpt_list);
-  curl_multi_remove_handle(mcurl, curl);
-  curl_multi_cleanup(mcurl);
+  curl_multi_remove_handle(multi, curl);
+  curl_multi_cleanup(multi);
   curl_easy_cleanup(curl);
   curl_global_cleanup();
 
-  return res;
+  return result;
 }
