@@ -29,31 +29,26 @@
  * because this implies that the data has been sent completely to the server.
  */
 
-#include "test.h"
-
-#include "memdebug.h"
+#include "first.h"
 
 struct cb_data {
-  CURL *easy_handle;
+  CURL *curl;
   int response_received;
   int paused;
   size_t remaining_bytes;
 };
 
-
 static void reset_data(struct cb_data *data, CURL *curl)
 {
-  data->easy_handle = curl;
+  data->curl = curl;
   data->response_received = 0;
   data->paused = 0;
   data->remaining_bytes = 3;
 }
 
-
-static size_t read_callback(char *ptr, size_t size, size_t nitems,
-                            void *userdata)
+static size_t t1533_read_cb(char *ptr, size_t size, size_t nitems, void *userp)
 {
-  struct cb_data *data = (struct cb_data *)userdata;
+  struct cb_data *data = (struct cb_data *)userp;
 
   /* wait until the server has sent all response headers */
   if(data->response_received) {
@@ -75,14 +70,11 @@ static size_t read_callback(char *ptr, size_t size, size_t nitems,
   }
 }
 
-
-static size_t write_callback(char *ptr, size_t size, size_t nmemb,
-                             void *userdata)
+static size_t t1533_write_cb(char *ptr, size_t size, size_t nmemb, void *userp)
 {
-  struct cb_data *data = (struct cb_data *)userdata;
+  struct cb_data *data = (struct cb_data *)userp;
   size_t totalsize = nmemb * size;
 
-  /* unused parameter */
   (void)ptr;
 
   /* all response headers have been received */
@@ -91,28 +83,27 @@ static size_t write_callback(char *ptr, size_t size, size_t nmemb,
   if(data->paused) {
     /* continue to send request body data */
     data->paused = 0;
-    curl_easy_pause(data->easy_handle, CURLPAUSE_CONT);
+    curl_easy_pause(data->curl, CURLPAUSE_CONT);
   }
 
   return totalsize;
 }
 
-
 static CURLcode perform_and_check_connections(CURL *curl,
                                               const char *description,
                                               long expected_connections)
 {
-  CURLcode res;
+  CURLcode result;
   long connections = 0;
 
-  res = curl_easy_perform(curl);
-  if(res != CURLE_OK) {
-    curl_mfprintf(stderr, "curl_easy_perform() failed with %d\n", res);
+  result = curl_easy_perform(curl);
+  if(result != CURLE_OK) {
+    curl_mfprintf(stderr, "curl_easy_perform() failed with %d\n", result);
     return TEST_ERR_MAJOR_BAD;
   }
 
-  res = curl_easy_getinfo(curl, CURLINFO_NUM_CONNECTS, &connections);
-  if(res != CURLE_OK) {
+  result = curl_easy_getinfo(curl, CURLINFO_NUM_CONNECTS, &connections);
+  if(result != CURLE_OK) {
     curl_mfprintf(stderr, "curl_easy_getinfo() failed\n");
     return TEST_ERR_MAJOR_BAD;
   }
@@ -128,13 +119,11 @@ static CURLcode perform_and_check_connections(CURL *curl,
   return TEST_ERR_SUCCESS;
 }
 
-
-CURLcode test(char *URL)
+static CURLcode test_lib1533(const char *URL)
 {
   struct cb_data data;
   CURL *curl = NULL;
-  CURLcode res = TEST_ERR_FAILURE;
-  CURLcode result;
+  CURLcode result = TEST_ERR_FAILURE;
 
   if(curl_global_init(CURL_GLOBAL_ALL) != CURLE_OK) {
     curl_mfprintf(stderr, "curl_global_init() failed\n");
@@ -155,15 +144,16 @@ CURLcode test(char *URL)
   test_setopt(curl, CURLOPT_POSTFIELDSIZE_LARGE,
               (curl_off_t)data.remaining_bytes);
   test_setopt(curl, CURLOPT_VERBOSE, 1L);
-  test_setopt(curl, CURLOPT_READFUNCTION, read_callback);
+  test_setopt(curl, CURLOPT_READFUNCTION, t1533_read_cb);
   test_setopt(curl, CURLOPT_READDATA, &data);
-  test_setopt(curl, CURLOPT_WRITEFUNCTION, write_callback);
+  test_setopt(curl, CURLOPT_WRITEFUNCTION, t1533_write_cb);
   test_setopt(curl, CURLOPT_WRITEDATA, &data);
 
-  result = perform_and_check_connections(curl,
-    "First request without CURLOPT_KEEP_SENDING_ON_ERROR", 1);
+  result =
+    perform_and_check_connections(curl,
+                                  "First request without "
+                                  "CURLOPT_KEEP_SENDING_ON_ERROR", 1);
   if(result != TEST_ERR_SUCCESS) {
-    res = result;
     goto test_cleanup;
   }
 
@@ -172,7 +162,6 @@ CURLcode test(char *URL)
   result = perform_and_check_connections(curl,
     "Second request without CURLOPT_KEEP_SENDING_ON_ERROR", 1);
   if(result != TEST_ERR_SUCCESS) {
-    res = result;
     goto test_cleanup;
   }
 
@@ -183,7 +172,6 @@ CURLcode test(char *URL)
   result = perform_and_check_connections(curl,
     "First request with CURLOPT_KEEP_SENDING_ON_ERROR", 1);
   if(result != TEST_ERR_SUCCESS) {
-    res = result;
     goto test_cleanup;
   }
 
@@ -192,17 +180,14 @@ CURLcode test(char *URL)
   result = perform_and_check_connections(curl,
     "Second request with CURLOPT_KEEP_SENDING_ON_ERROR", 0);
   if(result != TEST_ERR_SUCCESS) {
-    res = result;
     goto test_cleanup;
   }
 
-  res = TEST_ERR_SUCCESS;
+  result = TEST_ERR_SUCCESS;
 
 test_cleanup:
-
   curl_easy_cleanup(curl);
-
   curl_global_cleanup();
 
-  return res;
+  return result;
 }
