@@ -23,16 +23,14 @@
  ***************************************************************************/
 #include "first.h"
 
-#include "memdebug.h"
-
 #ifdef HAVE_PTHREAD_H
 #include <pthread.h>
 
-#define CONN_NUM 3
+#define CONN_NUM                3
 #define TIME_BETWEEN_START_SECS 2
 
 static pthread_mutex_t lock = PTHREAD_MUTEX_INITIALIZER;
-static CURL *pending_handles[CONN_NUM];
+static CURL *pending_curls[CONN_NUM];
 static int pending_num = 0;
 static CURLcode t1565_test_failure = CURLE_OK;
 
@@ -41,8 +39,8 @@ static const char *t1565_url;
 
 static void *t1565_run_thread(void *ptr)
 {
-  CURL *easy = NULL;
-  CURLcode res = CURLE_OK;
+  CURL *curl = NULL;
+  CURLcode result = CURLE_OK;
   int i;
 
   (void)ptr;
@@ -50,10 +48,10 @@ static void *t1565_run_thread(void *ptr)
   for(i = 0; i < CONN_NUM; i++) {
     curlx_wait_ms(TIME_BETWEEN_START_SECS * 1000);
 
-    easy_init(easy);
+    easy_init(curl);
 
-    easy_setopt(easy, CURLOPT_URL, t1565_url);
-    easy_setopt(easy, CURLOPT_VERBOSE, 0L);
+    easy_setopt(curl, CURLOPT_URL, t1565_url);
+    easy_setopt(curl, CURLOPT_VERBOSE, 0L);
 
     pthread_mutex_lock(&lock);
 
@@ -62,9 +60,9 @@ static void *t1565_run_thread(void *ptr)
       goto test_cleanup;
     }
 
-    pending_handles[pending_num] = easy;
+    pending_curls[pending_num] = curl;
     pending_num++;
-    easy = NULL;
+    curl = NULL;
 
     pthread_mutex_unlock(&lock);
 
@@ -73,12 +71,12 @@ static void *t1565_run_thread(void *ptr)
 
 test_cleanup:
 
-  curl_easy_cleanup(easy);
+  curl_easy_cleanup(curl);
 
   pthread_mutex_lock(&lock);
 
   if(!t1565_test_failure)
-    t1565_test_failure = res;
+    t1565_test_failure = result;
 
   pthread_mutex_unlock(&lock);
 
@@ -90,12 +88,12 @@ static CURLcode test_lib1565(const char *URL)
   int still_running;
   int num;
   int i;
-  int result;
-  CURLcode res = CURLE_OK;
-  CURL *started_handles[CONN_NUM];
+  int rc;
+  CURLcode result = CURLE_OK;
+  CURL *started_curls[CONN_NUM];
   int started_num = 0;
   int finished_num = 0;
-  pthread_t tid;
+  pthread_t tid = 0;
   bool tid_valid = false;
   struct CURLMsg *message;
 
@@ -107,12 +105,13 @@ static CURLcode test_lib1565(const char *URL)
 
   t1565_url = URL;
 
-  result = pthread_create(&tid, NULL, t1565_run_thread, NULL);
-  if(!result)
+  rc = pthread_create(&tid, NULL, t1565_run_thread, NULL);
+  if(!rc)
     tid_valid = true;
   else {
-    curl_mfprintf(stderr, "%s:%d Couldn't create thread, errno %d\n",
-                  __FILE__, __LINE__, result);
+    curl_mfprintf(stderr, "%s:%d Could not create thread, errno %d\n",
+                  __FILE__, __LINE__, rc);
+    result = CURLE_FAILED_INIT;
     goto test_cleanup;
   }
 
@@ -123,8 +122,8 @@ static CURLcode test_lib1565(const char *URL)
 
     while((message = curl_multi_info_read(testmulti, &num))) {
       if(message->msg == CURLMSG_DONE) {
-        res = message->data.result;
-        if(res)
+        result = message->data.result;
+        if(result)
           goto test_cleanup;
         multi_remove_handle(testmulti, message->easy_handle);
         finished_num++;
@@ -133,7 +132,7 @@ static CURLcode test_lib1565(const char *URL)
         curl_mfprintf(stderr,
                       "%s:%d Got an unexpected message from curl: %i\n",
                       __FILE__, __LINE__, message->msg);
-        res = TEST_ERR_MAJOR_BAD;
+        result = TEST_ERR_MAJOR_BAD;
         goto test_cleanup;
       }
 
@@ -150,13 +149,13 @@ static CURLcode test_lib1565(const char *URL)
     pthread_mutex_lock(&lock);
 
     while(pending_num > 0) {
-      res_multi_add_handle(testmulti, pending_handles[pending_num - 1]);
-      if(res) {
+      res_multi_add_handle(testmulti, pending_curls[pending_num - 1]);
+      if(result) {
         pthread_mutex_unlock(&lock);
         goto test_cleanup;
       }
 
-      started_handles[started_num] = pending_handles[pending_num - 1];
+      started_curls[started_num] = pending_curls[pending_num - 1];
       started_num++;
       pending_num--;
     }
@@ -182,7 +181,7 @@ test_cleanup:
 
   pthread_mutex_lock(&lock);
   if(!t1565_test_failure)
-    t1565_test_failure = res;
+    t1565_test_failure = result;
   pthread_mutex_unlock(&lock);
 
   if(tid_valid)
@@ -190,15 +189,15 @@ test_cleanup:
 
   curl_multi_cleanup(testmulti);
   for(i = 0; i < pending_num; i++)
-    curl_easy_cleanup(pending_handles[i]);
+    curl_easy_cleanup(pending_curls[i]);
   for(i = 0; i < started_num; i++)
-    curl_easy_cleanup(started_handles[i]);
+    curl_easy_cleanup(started_curls[i]);
   curl_global_cleanup();
 
   return t1565_test_failure;
 }
 
-#else /* without pthread, this test doesn't work */
+#else /* without pthread, this test does not work */
 static CURLcode test_lib1565(const char *URL)
 {
   (void)URL;
