@@ -21,36 +21,34 @@
  * SPDX-License-Identifier: curl
  *
  ***************************************************************************/
-#include "test.h"
+#include "first.h"
 
-#include "warnless.h"
-#include "memdebug.h"
-
-CURLcode test(char *URL)
+static CURLcode test_lib1916(const char *URL)
 {
   CURL *curl;
-  CURLcode res = CURLE_OK;
+  CURLcode result = CURLE_OK;
 
   if(curl_global_init(CURL_GLOBAL_ALL) != CURLE_OK) {
-    fprintf(stderr, "curl_global_init() failed\n");
+    curl_mfprintf(stderr, "curl_global_init() failed\n");
     return TEST_ERR_MAJOR_BAD;
   }
 
   curl = curl_easy_init();
   if(curl) {
     curl_easy_setopt(curl, CURLOPT_URL, URL);
-#ifdef LIB1917
-    /* without any postfields set! */
-    curl_easy_setopt(curl, CURLOPT_POST, 1L);
-#else
-    curl_easy_setopt(curl, CURLOPT_POSTFIELDS, "");
-#endif
-    res = curl_easy_perform(curl);
-    if(res) {
-      printf("res: %d\n", res);
+    if(testnum == 1917) {
+      /* without any postfields set! */
+      curl_easy_setopt(curl, CURLOPT_POST, 1L);
+    }
+    else {
+      curl_easy_setopt(curl, CURLOPT_POSTFIELDS, "");
+    }
+    result = curl_easy_perform(curl);
+    if(result) {
+      curl_mprintf("result: %d\n", result);
     }
     curl_easy_cleanup(curl);
   }
   curl_global_cleanup();
-  return res;
+  return result;
 }
