@@ -23,15 +23,13 @@
  ***************************************************************************/
 #include "first.h"
 
-#include "memdebug.h"
-
 static CURLcode test_lib3105(const char *URL)
 {
   CURL *curl = NULL;
   CURLM *multi = NULL;
   CURLcode i = CURLE_OK;
-  CURLcode res = CURLE_OK;
-  CURLMcode mc;
+  CURLcode result = CURLE_OK;
+  CURLMcode mresult;
 
   global_init(CURL_GLOBAL_ALL);
 
@@ -43,11 +41,12 @@ static CURLcode test_lib3105(const char *URL)
 
   multi_add_handle(multi, curl);
 
-  mc = curl_multi_remove_handle(multi, curl);
-  mc += curl_multi_remove_handle(multi, curl);
+  mresult = curl_multi_remove_handle(multi, curl);
+  if(!mresult)
+    mresult = curl_multi_remove_handle(multi, curl);
 
-  if(mc) {
-    curl_mfprintf(stderr, "%d was unexpected\n", mc);
+  if(mresult) {
+    curl_mfprintf(stderr, "%d was unexpected\n", mresult);
     i = CURLE_FAILED_INIT;
   }
 
@@ -56,8 +55,8 @@ test_cleanup:
   curl_easy_cleanup(curl);
   curl_global_cleanup();
 
-  if(res)
-    i = res;
+  if(result)
+    i = result;
 
   return i; /* return the final return code */
 }
