@@ -21,24 +21,15 @@
  * SPDX-License-Identifier: curl
  *
  ***************************************************************************/
-#include "test.h"
+#include "first.h"
 
-#ifdef HAVE_SYS_RESOURCE_H
-#include <sys/resource.h>
-#endif
-#ifdef HAVE_FCNTL_H
-#include <fcntl.h>
-#endif
-#include <limits.h>
-
-#include "warnless.h"
-#include "memdebug.h"
+#include "testutil.h"
 
 #if !defined(HAVE_POLL) && !defined(USE_WINSOCK) && !defined(FD_SETSIZE)
 #error "this test requires FD_SETSIZE"
 #endif
 
-#define SAFETY_MARGIN (11)
+#define T537_SAFETY_MARGIN (11)
 
 #if defined(_WIN32) || defined(MSDOS)
 #define DEV_NULL "NUL"
@@ -48,31 +39,33 @@
 
 #if defined(HAVE_GETRLIMIT) && defined(HAVE_SETRLIMIT)
 
-static int *testfd = NULL;
-static struct rlimit num_open;
-static char msgbuff[256];
+static int *t537_testfd = NULL;
+static struct rlimit t537_num_open;
+static char t537_msgbuff[256];
 
-static void store_errmsg(const char *msg, int err)
+static void t537_store_errmsg(const char *msg, int err)
 {
   if(!err)
-    curl_msnprintf(msgbuff, sizeof(msgbuff), "%s", msg);
-  else
-    curl_msnprintf(msgbuff, sizeof(msgbuff), "%s, errno %d, %s", msg,
-              err, strerror(err));
+    curl_msnprintf(t537_msgbuff, sizeof(t537_msgbuff), "%s", msg);
+  else {
+    char errbuf[STRERROR_LEN];
+    curl_msnprintf(t537_msgbuff, sizeof(t537_msgbuff), "%s, errno %d, %s", msg,
+                   err, curlx_strerror(err, errbuf, sizeof(errbuf)));
+  }
 }
 
-static void close_file_descriptors(void)
+static void t537_close_file_descriptors(void)
 {
-  for(num_open.rlim_cur = 0;
-      num_open.rlim_cur < num_open.rlim_max;
-      num_open.rlim_cur++)
-    if(testfd[num_open.rlim_cur] > 0)
-      close(testfd[num_open.rlim_cur]);
-  free(testfd);
-  testfd = NULL;
+  for(t537_num_open.rlim_cur = 0;
+      t537_num_open.rlim_cur < t537_num_open.rlim_max;
+      t537_num_open.rlim_cur++)
+    if(t537_testfd[t537_num_open.rlim_cur] > 0)
+      close(t537_testfd[t537_num_open.rlim_cur]);
+  curlx_free(t537_testfd);
+  t537_testfd = NULL;
 }
 
-static int fopen_works(void)
+static int t537_fopen_works(void)
 {
   FILE *fpa[3];
   int i;
@@ -82,43 +75,22 @@ static int fopen_works(void)
     fpa[i] = NULL;
   }
   for(i = 0; i < 3; i++) {
-    fpa[i] = fopen(DEV_NULL, FOPEN_READTEXT);
+    fpa[i] = curlx_fopen(DEV_NULL, FOPEN_READTEXT);
     if(!fpa[i]) {
-      store_errmsg("fopen failed", errno);
-      curl_mfprintf(stderr, "%s\n", msgbuff);
+      t537_store_errmsg("fopen failed", errno);
+      curl_mfprintf(stderr, "%s\n", t537_msgbuff);
       ret = 0;
       break;
     }
   }
   for(i = 0; i < 3; i++) {
     if(fpa[i])
-      fclose(fpa[i]);
+      curlx_fclose(fpa[i]);
   }
   return ret;
 }
 
-static void rlim2str(char *buf, size_t len, rlim_t val)
-{
-#ifdef RLIM_INFINITY
-  if(val == RLIM_INFINITY) {
-    curl_msnprintf(buf, len, "INFINITY");
-    return;
-  }
-#endif
-#ifdef HAVE_LONGLONG
-  if(sizeof(rlim_t) > sizeof(long))
-    curl_msnprintf(buf, len, "%llu", (unsigned long long)val);
-  else
-#endif
-  {
-    if(sizeof(rlim_t) < sizeof(long))
-      curl_msnprintf(buf, len, "%u", (unsigned int)val);
-    else
-      curl_msnprintf(buf, len, "%lu", (unsigned long)val);
-  }
-}
-
-static int test_rlimit(int keep_open)
+static int t537_test_rlimit(int keep_open)
 {
   int *tmpfd;
   rlim_t nitems, i;
@@ -130,23 +102,23 @@ static int test_rlimit(int keep_open)
   /* get initial open file limits */
 
   if(getrlimit(RLIMIT_NOFILE, &rl) != 0) {
-    store_errmsg("getrlimit() failed", errno);
-    curl_mfprintf(stderr, "%s\n", msgbuff);
+    t537_store_errmsg("getrlimit() failed", errno);
+    curl_mfprintf(stderr, "%s\n", t537_msgbuff);
     return -1;
   }
 
   /* show initial open file limits */
 
-  rlim2str(strbuff, sizeof(strbuff), rl.rlim_cur);
+  tutil_rlim2str(strbuff, sizeof(strbuff), rl.rlim_cur);
   curl_mfprintf(stderr, "initial soft limit: %s\n", strbuff);
 
-  rlim2str(strbuff, sizeof(strbuff), rl.rlim_max);
+  tutil_rlim2str(strbuff, sizeof(strbuff), rl.rlim_max);
   curl_mfprintf(stderr, "initial hard limit: %s\n", strbuff);
 
   /* If the OS allows a HUGE number of open files, we do not run.
    * Modern debian sid reports a limit of 134217724 and this tests
    * takes minutes. */
-#define LIMIT_CAP     (256*1024)
+#define LIMIT_CAP (256 * 1024)
   if(rl.rlim_cur > LIMIT_CAP) {
     curl_mfprintf(stderr, "soft limit above %ld, not running\n",
                   (long)LIMIT_CAP);
@@ -170,10 +142,10 @@ static int test_rlimit(int keep_open)
       curl_mfprintf(stderr, "raising soft limit up to OPEN_MAX\n");
       rl.rlim_cur = OPEN_MAX;
       if(setrlimit(RLIMIT_NOFILE, &rl) != 0) {
-        /* on failure don't abort just issue a warning */
-        store_errmsg("setrlimit() failed", errno);
-        curl_mfprintf(stderr, "%s\n", msgbuff);
-        msgbuff[0] = '\0';
+        /* on failure do not abort just issue a warning */
+        t537_store_errmsg("setrlimit() failed", errno);
+        curl_mfprintf(stderr, "%s\n", t537_msgbuff);
+        t537_msgbuff[0] = '\0';
       }
     }
 #endif
@@ -181,26 +153,26 @@ static int test_rlimit(int keep_open)
     curl_mfprintf(stderr, "raising soft limit up to hard limit\n");
     rl.rlim_cur = rl.rlim_max;
     if(setrlimit(RLIMIT_NOFILE, &rl) != 0) {
-      /* on failure don't abort just issue a warning */
-      store_errmsg("setrlimit() failed", errno);
-      curl_mfprintf(stderr, "%s\n", msgbuff);
-      msgbuff[0] = '\0';
+      /* on failure do not abort just issue a warning */
+      t537_store_errmsg("setrlimit() failed", errno);
+      curl_mfprintf(stderr, "%s\n", t537_msgbuff);
+      t537_msgbuff[0] = '\0';
     }
 
     /* get current open file limits */
 
     if(getrlimit(RLIMIT_NOFILE, &rl) != 0) {
-      store_errmsg("getrlimit() failed", errno);
-      curl_mfprintf(stderr, "%s\n", msgbuff);
+      t537_store_errmsg("getrlimit() failed", errno);
+      curl_mfprintf(stderr, "%s\n", t537_msgbuff);
       return -3;
     }
 
     /* show current open file limits */
 
-    rlim2str(strbuff, sizeof(strbuff), rl.rlim_cur);
+    tutil_rlim2str(strbuff, sizeof(strbuff), rl.rlim_cur);
     curl_mfprintf(stderr, "current soft limit: %s\n", strbuff);
 
-    rlim2str(strbuff, sizeof(strbuff), rl.rlim_max);
+    tutil_rlim2str(strbuff, sizeof(strbuff), rl.rlim_max);
     curl_mfprintf(stderr, "current hard limit: %s\n", strbuff);
 
   } /* (rl.rlim_cur != rl.rlim_max) */
@@ -209,7 +181,7 @@ static int test_rlimit(int keep_open)
    * test 537 is all about testing libcurl functionality
    * when the system has nearly exhausted the number of
    * available file descriptors. Test 537 will try to run
-   * with a very small number of file descriptors available.
+   * with a small number of file descriptors available.
    * This implies that any file descriptor which is open
    * when the test runs will have a number in the high range
    * of whatever the system supports.
@@ -220,8 +192,8 @@ static int test_rlimit(int keep_open)
    * avoid a low memory condition once the file descriptors are
    * open. System conditions that could make the test fail should
    * be addressed in the precheck phase. This chunk of memory shall
-   * be always free()ed before exiting the test_rlimit() function so
-   * that it becomes available to the test.
+   * be always curlx_free()ed before exiting the t537_test_rlimit()
+   * function so that it becomes available to the test.
    */
 
   for(nitems = i = 1; nitems <= i; i *= 2)
@@ -229,18 +201,18 @@ static int test_rlimit(int keep_open)
   if(nitems > 0x7fff)
     nitems = 0x40000;
   do {
-    num_open.rlim_max = sizeof(*memchunk) * nitems;
-    rlim2str(strbuff, sizeof(strbuff), num_open.rlim_max);
+    t537_num_open.rlim_max = sizeof(*memchunk) * nitems;
+    tutil_rlim2str(strbuff, sizeof(strbuff), t537_num_open.rlim_max);
     curl_mfprintf(stderr, "allocating memchunk %s byte array\n", strbuff);
-    memchunk = malloc(sizeof(*memchunk) * (size_t)nitems);
+    memchunk = curlx_malloc(sizeof(*memchunk) * (size_t)nitems);
     if(!memchunk) {
       curl_mfprintf(stderr, "memchunk, malloc() failed\n");
       nitems /= 2;
     }
   } while(nitems && !memchunk);
   if(!memchunk) {
-    store_errmsg("memchunk, malloc() failed", errno);
-    curl_mfprintf(stderr, "%s\n", msgbuff);
+    t537_store_errmsg("memchunk, malloc() failed", errno);
+    curl_mfprintf(stderr, "%s\n", t537_msgbuff);
     return -4;
   }
 
@@ -258,8 +230,8 @@ static int test_rlimit(int keep_open)
 #else
   if(rl.rlim_cur > 0) {
 #endif
-    /* soft limit minus SAFETY_MARGIN */
-    num_open.rlim_max = rl.rlim_cur - SAFETY_MARGIN;
+    /* soft limit minus T537_SAFETY_MARGIN */
+    t537_num_open.rlim_max = rl.rlim_cur - T537_SAFETY_MARGIN;
   }
   else {
     /* a huge number of file descriptors */
@@ -267,39 +239,40 @@ static int test_rlimit(int keep_open)
       nitems = i;
     if(nitems > 0x7fff)
       nitems = 0x40000;
-    num_open.rlim_max = nitems;
+    t537_num_open.rlim_max = nitems;
   }
 
-  /* verify that we won't overflow size_t in malloc() */
+  /* verify that we do not overflow size_t in curlx_malloc() */
 
-  if((size_t)(num_open.rlim_max) > ((size_t)-1) / sizeof(*testfd)) {
-    rlim2str(strbuff1, sizeof(strbuff1), num_open.rlim_max);
+  if((size_t)(t537_num_open.rlim_max) > ((size_t)-1) / sizeof(*t537_testfd)) {
+    tutil_rlim2str(strbuff1, sizeof(strbuff1), t537_num_open.rlim_max);
     curl_msnprintf(strbuff, sizeof(strbuff),
                    "unable to allocate an array for %s "
                    "file descriptors, would overflow size_t", strbuff1);
-    store_errmsg(strbuff, 0);
-    curl_mfprintf(stderr, "%s\n", msgbuff);
-    free(memchunk);
+    t537_store_errmsg(strbuff, 0);
+    curl_mfprintf(stderr, "%s\n", t537_msgbuff);
+    curlx_free(memchunk);
     return -5;
   }
 
   /* allocate array for file descriptors */
 
   do {
-    rlim2str(strbuff, sizeof(strbuff), num_open.rlim_max);
+    tutil_rlim2str(strbuff, sizeof(strbuff), t537_num_open.rlim_max);
     curl_mfprintf(stderr, "allocating array for %s file descriptors\n",
                   strbuff);
 
-    testfd = malloc(sizeof(*testfd) * (size_t)(num_open.rlim_max));
-    if(!testfd) {
+    t537_testfd = curlx_malloc(sizeof(*t537_testfd) *
+                               (size_t)(t537_num_open.rlim_max));
+    if(!t537_testfd) {
       curl_mfprintf(stderr, "testfd, malloc() failed\n");
-      num_open.rlim_max /= 2;
+      t537_num_open.rlim_max /= 2;
     }
-  } while(num_open.rlim_max && !testfd);
-  if(!testfd) {
-    store_errmsg("testfd, malloc() failed", errno);
-    curl_mfprintf(stderr, "%s\n", msgbuff);
-    free(memchunk);
+  } while(t537_num_open.rlim_max && !t537_testfd);
+  if(!t537_testfd) {
+    t537_store_errmsg("testfd, malloc() failed", errno);
+    curl_mfprintf(stderr, "%s\n", t537_msgbuff);
+    curlx_free(memchunk);
     return -6;
   }
 
@@ -307,73 +280,75 @@ static int test_rlimit(int keep_open)
 
   curl_mfprintf(stderr, "initializing testfd array\n");
 
-  for(num_open.rlim_cur = 0;
-      num_open.rlim_cur < num_open.rlim_max;
-      num_open.rlim_cur++)
-    testfd[num_open.rlim_cur] = -1;
+  for(t537_num_open.rlim_cur = 0;
+      t537_num_open.rlim_cur < t537_num_open.rlim_max;
+      t537_num_open.rlim_cur++)
+    t537_testfd[t537_num_open.rlim_cur] = -1;
 
-  rlim2str(strbuff, sizeof(strbuff), num_open.rlim_max);
+  tutil_rlim2str(strbuff, sizeof(strbuff), t537_num_open.rlim_max);
   curl_mfprintf(stderr, "trying to open %s file descriptors\n", strbuff);
 
   /* open a dummy descriptor */
 
-  testfd[0] = open(DEV_NULL, O_RDONLY);
-  if(testfd[0] < 0) {
+  t537_testfd[0] = curlx_open(DEV_NULL, O_RDONLY);
+  if(t537_testfd[0] < 0) {
     curl_msnprintf(strbuff, sizeof(strbuff), "opening of %s failed", DEV_NULL);
-    store_errmsg(strbuff, errno);
-    curl_mfprintf(stderr, "%s\n", msgbuff);
-    free(testfd);
-    testfd = NULL;
-    free(memchunk);
+    t537_store_errmsg(strbuff, errno);
+    curl_mfprintf(stderr, "%s\n", t537_msgbuff);
+    curlx_free(t537_testfd);
+    t537_testfd = NULL;
+    curlx_free(memchunk);
     return -7;
   }
 
   /* create a bunch of file descriptors */
 
-  for(num_open.rlim_cur = 1;
-      num_open.rlim_cur < num_open.rlim_max;
-      num_open.rlim_cur++) {
+  for(t537_num_open.rlim_cur = 1;
+      t537_num_open.rlim_cur < t537_num_open.rlim_max;
+      t537_num_open.rlim_cur++) {
 
-    testfd[num_open.rlim_cur] = dup(testfd[0]);
+    t537_testfd[t537_num_open.rlim_cur] = dup(t537_testfd[0]);
 
-    if(testfd[num_open.rlim_cur] < 0) {
+    if(t537_testfd[t537_num_open.rlim_cur] < 0) {
 
-      testfd[num_open.rlim_cur] = -1;
+      t537_testfd[t537_num_open.rlim_cur] = -1;
 
-      rlim2str(strbuff1, sizeof(strbuff1), num_open.rlim_cur);
+      tutil_rlim2str(strbuff1, sizeof(strbuff1), t537_num_open.rlim_cur);
       curl_msnprintf(strbuff, sizeof(strbuff), "dup() attempt %s failed",
                      strbuff1);
       curl_mfprintf(stderr, "%s\n", strbuff);
 
-      rlim2str(strbuff1, sizeof(strbuff1), num_open.rlim_cur);
+      tutil_rlim2str(strbuff1, sizeof(strbuff1), t537_num_open.rlim_cur);
       curl_msnprintf(strbuff, sizeof(strbuff),
                      "fds system limit seems close to %s", strbuff1);
       curl_mfprintf(stderr, "%s\n", strbuff);
 
-      num_open.rlim_max = num_open.rlim_cur - SAFETY_MARGIN;
+      t537_num_open.rlim_max = t537_num_open.rlim_cur - T537_SAFETY_MARGIN;
 
-      num_open.rlim_cur -= num_open.rlim_max;
-      rlim2str(strbuff1, sizeof(strbuff1), num_open.rlim_cur);
+      t537_num_open.rlim_cur -= t537_num_open.rlim_max;
+      tutil_rlim2str(strbuff1, sizeof(strbuff1), t537_num_open.rlim_cur);
       curl_msnprintf(strbuff, sizeof(strbuff), "closing %s file descriptors",
                      strbuff1);
       curl_mfprintf(stderr, "%s\n", strbuff);
 
-      for(num_open.rlim_cur = num_open.rlim_max;
-          testfd[num_open.rlim_cur] >= 0;
-          num_open.rlim_cur++) {
-        close(testfd[num_open.rlim_cur]);
-        testfd[num_open.rlim_cur] = -1;
+      for(t537_num_open.rlim_cur = t537_num_open.rlim_max;
+          t537_testfd[t537_num_open.rlim_cur] >= 0;
+          t537_num_open.rlim_cur++) {
+        close(t537_testfd[t537_num_open.rlim_cur]);
+        t537_testfd[t537_num_open.rlim_cur] = -1;
       }
 
-      rlim2str(strbuff, sizeof(strbuff), num_open.rlim_max);
+      tutil_rlim2str(strbuff, sizeof(strbuff), t537_num_open.rlim_max);
       curl_mfprintf(stderr, "shrinking array for %s file descriptors\n",
                     strbuff);
 
-      /* we don't care if we can't shrink it */
+      /* we do not care if we cannot shrink it */
 
-      tmpfd = realloc(testfd, sizeof(*testfd) * (size_t)(num_open.rlim_max));
+      tmpfd = curlx_realloc(t537_testfd,
+                            sizeof(*t537_testfd) *
+                            (size_t)(t537_num_open.rlim_max));
       if(tmpfd) {
-        testfd = tmpfd;
+        t537_testfd = tmpfd;
         tmpfd = NULL;
       }
 
@@ -381,7 +356,7 @@ static int test_rlimit(int keep_open)
     }
   }
 
-  rlim2str(strbuff, sizeof(strbuff), num_open.rlim_max);
+  tutil_rlim2str(strbuff, sizeof(strbuff), t537_num_open.rlim_max);
   curl_mfprintf(stderr, "%s file descriptors open\n", strbuff);
 
 #if !defined(HAVE_POLL) && !defined(USE_WINSOCK)
@@ -397,29 +372,29 @@ static int test_rlimit(int keep_open)
    * with an indication that select limit would be exceeded.
    */
 
-  num_open.rlim_cur = FD_SETSIZE - SAFETY_MARGIN;
-  if(num_open.rlim_max > num_open.rlim_cur) {
+  t537_num_open.rlim_cur = FD_SETSIZE - T537_SAFETY_MARGIN;
+  if(t537_num_open.rlim_max > t537_num_open.rlim_cur) {
     curl_msnprintf(strbuff, sizeof(strbuff), "select limit is FD_SETSIZE %d",
-              FD_SETSIZE);
-    store_errmsg(strbuff, 0);
-    curl_mfprintf(stderr, "%s\n", msgbuff);
-    close_file_descriptors();
-    free(memchunk);
+                   FD_SETSIZE);
+    t537_store_errmsg(strbuff, 0);
+    curl_mfprintf(stderr, "%s\n", t537_msgbuff);
+    t537_close_file_descriptors();
+    curlx_free(memchunk);
     return -8;
   }
 
-  num_open.rlim_cur = FD_SETSIZE - SAFETY_MARGIN;
+  t537_num_open.rlim_cur = FD_SETSIZE - T537_SAFETY_MARGIN;
   for(rl.rlim_cur = 0;
-      rl.rlim_cur < num_open.rlim_max;
+      rl.rlim_cur < t537_num_open.rlim_max;
       rl.rlim_cur++) {
-    if((testfd[rl.rlim_cur] > 0) &&
-       ((unsigned int)testfd[rl.rlim_cur] > num_open.rlim_cur)) {
+    if((t537_testfd[rl.rlim_cur] > 0) &&
+       ((unsigned int)t537_testfd[rl.rlim_cur] > t537_num_open.rlim_cur)) {
       curl_msnprintf(strbuff, sizeof(strbuff), "select limit is FD_SETSIZE %d",
-                FD_SETSIZE);
-      store_errmsg(strbuff, 0);
-      curl_mfprintf(stderr, "%s\n", msgbuff);
-      close_file_descriptors();
-      free(memchunk);
+                     FD_SETSIZE);
+      t537_store_errmsg(strbuff, 0);
+      curl_mfprintf(stderr, "%s\n", t537_msgbuff);
+      t537_close_file_descriptors();
+      curlx_free(memchunk);
       return -9;
     }
   }
@@ -435,48 +410,48 @@ static int test_rlimit(int keep_open)
    * if it is capable of fopen()ing some additional files.
    */
 
-  if(!fopen_works()) {
-    rlim2str(strbuff1, sizeof(strbuff1), num_open.rlim_max);
+  if(!t537_fopen_works()) {
+    tutil_rlim2str(strbuff1, sizeof(strbuff1), t537_num_open.rlim_max);
     curl_msnprintf(strbuff, sizeof(strbuff), "fopen fails with %s fds open",
                    strbuff1);
-    curl_mfprintf(stderr, "%s\n", msgbuff);
+    curl_mfprintf(stderr, "%s\n", t537_msgbuff);
     curl_msnprintf(strbuff, sizeof(strbuff),
                    "fopen fails with lots of fds open");
-    store_errmsg(strbuff, 0);
-    close_file_descriptors();
-    free(memchunk);
+    t537_store_errmsg(strbuff, 0);
+    t537_close_file_descriptors();
+    curlx_free(memchunk);
     return -10;
   }
 
   /* free the chunk of memory we were reserving so that it
      becomes available to the test */
 
-  free(memchunk);
+  curlx_free(memchunk);
 
   /* close file descriptors unless instructed to keep them */
 
   if(!keep_open) {
-    close_file_descriptors();
+    t537_close_file_descriptors();
   }
 
   return 0;
 }
 
-CURLcode test(char *URL)
+static CURLcode test_lib537(const char *URL)
 {
-  CURLcode res;
+  CURLcode result;
   CURL *curl;
 
   if(!strcmp(URL, "check")) {
     /* used by the test script to ask if we can run this test or not */
-    if(test_rlimit(FALSE)) {
-      curl_mfprintf(stdout, "test_rlimit problem: %s\n", msgbuff);
+    if(t537_test_rlimit(FALSE)) {
+      curl_mfprintf(stdout, "test_rlimit problem: %s\n", t537_msgbuff);
       return TEST_ERR_FAILURE;
     }
     return CURLE_OK; /* sure, run this! */
   }
 
-  if(test_rlimit(TRUE)) {
+  if(t537_test_rlimit(TRUE)) {
     /* failure */
     return TEST_ERR_MAJOR_BAD;
   }
@@ -486,14 +461,14 @@ CURLcode test(char *URL)
 
   if(curl_global_init(CURL_GLOBAL_ALL) != CURLE_OK) {
     curl_mfprintf(stderr, "curl_global_init() failed\n");
-    close_file_descriptors();
+    t537_close_file_descriptors();
     return TEST_ERR_MAJOR_BAD;
   }
 
   curl = curl_easy_init();
   if(!curl) {
     curl_mfprintf(stderr, "curl_easy_init() failed\n");
-    close_file_descriptors();
+    t537_close_file_descriptors();
     curl_global_cleanup();
     return TEST_ERR_MAJOR_BAD;
   }
@@ -501,24 +476,24 @@ CURLcode test(char *URL)
   test_setopt(curl, CURLOPT_URL, URL);
   test_setopt(curl, CURLOPT_HEADER, 1L);
 
-  res = curl_easy_perform(curl);
+  result = curl_easy_perform(curl);
 
 test_cleanup:
 
-  close_file_descriptors();
+  t537_close_file_descriptors();
   curl_easy_cleanup(curl);
   curl_global_cleanup();
 
-  return res;
+  return result;
 }
 
-#else /* defined(HAVE_GETRLIMIT) && defined(HAVE_SETRLIMIT) */
+#else /* HAVE_GETRLIMIT && HAVE_SETRLIMIT */
 
-CURLcode test(char *URL)
+static CURLcode test_lib537(const char *URL)
 {
   (void)URL;
   curl_mprintf("system lacks necessary system function(s)");
   return TEST_ERR_MAJOR_BAD; /* skip test */
 }
 
-#endif /* defined(HAVE_GETRLIMIT) && defined(HAVE_SETRLIMIT) */
+#endif /* HAVE_GETRLIMIT && HAVE_SETRLIMIT */
