@@ -23,11 +23,9 @@
  ***************************************************************************/
 #include "first.h"
 
-#include "memdebug.h"
-
-static CURLcode test_lib556(char *URL)
+static CURLcode test_lib556(const char *URL)
 {
-  CURLcode res;
+  CURLcode result;
   CURL *curl;
   int transfers = 0;
 
@@ -49,23 +47,25 @@ static CURLcode test_lib556(char *URL)
 
 again:
 
-  res = curl_easy_perform(curl);
+  result = curl_easy_perform(curl);
 
-  if(!res) {
+  if(!result) {
     /* we are connected, now get an HTTP document the raw way */
-    static const char *request =
-      "GET /556 HTTP/1.1\r\n"
-      "Host: ninja\r\n\r\n";
+    char request[64];
     const char *sbuf = request;
-    size_t sblen = strlen(request);
+    size_t sblen;
     size_t nwritten = 0, nread = 0;
 
+    sblen = curl_msnprintf(request, sizeof(request),
+                           "GET /%d HTTP/1.1\r\n"
+                           "Host: ninja\r\n\r\n", testnum);
+
     do {
       char buf[1024];
 
       if(sblen) {
-        res = curl_easy_send(curl, sbuf, sblen, &nwritten);
-        if(res && res != CURLE_AGAIN)
+        result = curl_easy_send(curl, sbuf, sblen, &nwritten);
+        if(result && result != CURLE_AGAIN)
           break;
         if(nwritten > 0) {
           sbuf += nwritten;
@@ -74,32 +74,29 @@ again:
       }
 
       /* busy-read like crazy */
-      res = curl_easy_recv(curl, buf, sizeof(buf), &nread);
+      result = curl_easy_recv(curl, buf, sizeof(buf), &nread);
 
       if(nread) {
         /* send received stuff to stdout */
-#ifdef UNDER_CE
-        if((size_t)fwrite(buf, sizeof(buf[0]), nread, stdout) != nread) {
-#else
         if((size_t)write(STDOUT_FILENO, buf, nread) != nread) {
-#endif
+          char errbuf[STRERROR_LEN];
           curl_mfprintf(stderr, "write() failed: errno %d (%s)\n",
-                        errno, strerror(errno));
-          res = TEST_ERR_FAILURE;
+                        errno, curlx_strerror(errno, errbuf, sizeof(errbuf)));
+          result = TEST_ERR_FAILURE;
           break;
         }
       }
 
-    } while((res == CURLE_OK && nread) || (res == CURLE_AGAIN));
+    } while((result == CURLE_OK && nread) || (result == CURLE_AGAIN));
 
-    if(res && res != CURLE_AGAIN)
-      res = TEST_ERR_FAILURE;
+    if(result && result != CURLE_AGAIN)
+      result = TEST_ERR_FAILURE;
   }
 
   if(testnum == 696) {
     ++transfers;
     /* perform the transfer a second time */
-    if(!res && transfers == 1)
+    if(!result && transfers == 1)
       goto again;
   }
 
@@ -108,5 +105,5 @@ test_cleanup:
   curl_easy_cleanup(curl);
   curl_global_cleanup();
 
-  return res;
+  return result;
 }
