@@ -24,11 +24,10 @@
 #include "first.h"
 
 #include "testutil.h"
-#include "memdebug.h"
 
-static CURLcode test_lib570(char *URL)
+static CURLcode test_lib570(const char *URL)
 {
-  CURLcode res;
+  CURLcode result;
   CURL *curl;
   int request = 1;
   char *stream_uri = NULL;
@@ -55,56 +54,56 @@ static CURLcode test_lib570(char *URL)
 
   stream_uri = tutil_suburl(URL, request++);
   if(!stream_uri) {
-    res = TEST_ERR_MAJOR_BAD;
+    result = TEST_ERR_MAJOR_BAD;
     goto test_cleanup;
   }
   test_setopt(curl, CURLOPT_RTSP_STREAM_URI, stream_uri);
   curl_free(stream_uri);
   stream_uri = NULL;
 
-  res = curl_easy_perform(curl);
-  if(res != (int)CURLE_RTSP_CSEQ_ERROR) {
+  result = curl_easy_perform(curl);
+  if(result != CURLE_RTSP_CSEQ_ERROR) {
     curl_mfprintf(stderr, "Failed to detect CSeq mismatch");
-    res = TEST_ERR_MAJOR_BAD;
+    result = TEST_ERR_MAJOR_BAD;
     goto test_cleanup;
   }
 
   test_setopt(curl, CURLOPT_RTSP_CLIENT_CSEQ, 999L);
   test_setopt(curl, CURLOPT_RTSP_TRANSPORT,
-                    "RAW/RAW/UDP;unicast;client_port=3056-3057");
+              "RAW/RAW/UDP;unicast;client_port=3056-3057");
   test_setopt(curl, CURLOPT_RTSP_REQUEST, CURL_RTSPREQ_SETUP);
 
   stream_uri = tutil_suburl(URL, request++);
   if(!stream_uri) {
-    res = TEST_ERR_MAJOR_BAD;
+    result = TEST_ERR_MAJOR_BAD;
     goto test_cleanup;
   }
   test_setopt(curl, CURLOPT_RTSP_STREAM_URI, stream_uri);
   curl_free(stream_uri);
   stream_uri = NULL;
 
-  res = curl_easy_perform(curl);
-  if(res)
+  result = curl_easy_perform(curl);
+  if(result)
     goto test_cleanup;
 
   test_setopt(curl, CURLOPT_RTSP_REQUEST, CURL_RTSPREQ_PLAY);
 
   stream_uri = tutil_suburl(URL, request++);
   if(!stream_uri) {
-    res = TEST_ERR_MAJOR_BAD;
+    result = TEST_ERR_MAJOR_BAD;
     goto test_cleanup;
   }
   test_setopt(curl, CURLOPT_RTSP_STREAM_URI, stream_uri);
   curl_free(stream_uri);
   stream_uri = NULL;
 
-  res = curl_easy_perform(curl);
-  if(res == CURLE_RTSP_SESSION_ERROR) {
-    res = CURLE_OK;
+  result = curl_easy_perform(curl);
+  if(result == CURLE_RTSP_SESSION_ERROR) {
+    result = CURLE_OK;
   }
   else {
     curl_mfprintf(stderr, "Failed to detect a Session ID mismatch");
-    res = TEST_ERR_FAILURE;
+    result = TEST_ERR_FAILURE;
   }
 
 test_cleanup:
@@ -113,5 +112,5 @@ test_cleanup:
   curl_easy_cleanup(curl);
   curl_global_cleanup();
 
-  return res;
+  return result;
 }
