@@ -74,7 +74,6 @@ my @not_built_in_num = (
     'CURLOPT_SOCKS5_AUTH',
     );
 
-
 #
 # Generate a set of string checks
 #
@@ -174,7 +173,7 @@ MOO
     ;
 
 if(!$ARGV[0]) {
-    die "missing target file name";
+    die "missing target filename";
 }
 
 use File::Temp qw/ :mktemp  /;
@@ -206,7 +205,6 @@ print $fh <<HEADER
  *
  ***************************************************************************/
 #include "first.h"
-#include "memdebug.h"
 
 /* This source code is generated by mk-lib1521.pl ! */
 
@@ -374,14 +372,14 @@ static CURLcode test_lib1521(const char *URL)
   struct curl_certinfo *certinfo;
   struct curl_tlssessioninfo *tlssession;
   struct curl_blob blob = { CURL_UNCONST("silly"), 5, 0};
-  CURLcode res = CURLE_OK;
+  CURLcode result = CURLE_OK;
   (void)URL;
   global_init(CURL_GLOBAL_ALL);
   easy_init(dep);
   easy_init(curl);
   share = curl_share_init();
   if(!share) {
-    res = CURLE_OUT_OF_MEMORY;
+    result = CURLE_OUT_OF_MEMORY;
     goto test_cleanup;
   }
 
@@ -449,7 +447,10 @@ while(<STDIN>) {
         # the first check for an option
         my $fpref = "${exists}${w2}CURLcode first =\n${w3}curl_easy_setopt(curl, $name,";
         my $ifpresent = "${w2}if(present(first)) {\n";
-        my $pref = "${w3}res = curl_easy_setopt(curl, $name,";
+        my $pref = "${w3}result =\n".
+                   "${w3}  curl_easy_setopt(curl, $name,";
+        my $ignoreset = "${w3}/* set string again to check for leaks */\n".
+            "${w3}(void)curl_easy_setopt(curl, $name,";
         my $i = ' ' x (length($w) + 25);
         my $fcheck = <<MOO
     if(first && present(first)) /* first setopt check only */
@@ -462,8 +463,8 @@ MOO
 MOO
             ;
         my $check = <<MOO
-      if(res)
-        err("$name", res, __LINE__);
+      if(result)
+        err("$name", result, __LINE__);
 MOO
             ;
         my $flongcheckzero = <<MOO
@@ -474,20 +475,20 @@ MOO
             ;
 
         my $longcheck = <<MOO
-      if(res && !bad_long(res, $name))
-        errlong("$name", res, __LINE__);
+      if(result && !bad_long(result, $name))
+        errlong("$name", result, __LINE__);
 MOO
             ;
 
         my $negcheck = <<MOO
-      if(res && bad_neg($name))
-        errneg("$name", res, __LINE__);
+      if(result && bad_neg($name))
+        errneg("$name", result, __LINE__);
 MOO
             ;
 
         my $nullcheck = <<MOO
-      if(res)
-        errnull(\"$name\", res, __LINE__);
+      if(result)
+        errnull(\"$name\", result, __LINE__);
 MOO
             ;
 
@@ -495,6 +496,7 @@ MOO
         if($type eq "CURLOPTTYPE_STRINGPOINT") {
             print $fh "${fpref} \"string\");\n$fstringcheck";
             print $fh "$ifpresent";
+            print $fh "${ignoreset} \"\");\n";
             print $fh "${pref} NULL);\n$nullcheck";
         }
         elsif(($type eq "CURLOPTTYPE_LONG") ||
@@ -588,8 +590,8 @@ MOO
     elsif($infomode &&
           ($_ =~ /^CURLINFO_([^ ]*) *= *CURLINFO_([^ ]*)/)) {
        my ($info, $type)=($1, $2);
-       my $c = "  res = curl_easy_getinfo(curl, CURLINFO_$info,";
-       my $check = "  if(res)\n    t1521_geterr(\"$info\", res, __LINE__);\n";
+       my $c = "  result = curl_easy_getinfo(curl, CURLINFO_$info,";
+       my $check = "  if(result)\n    t1521_geterr(\"$info\", result, __LINE__);\n";
        if($type eq "STRING") {
          print $fh "$c &charp);\n$check";
        }
@@ -627,21 +629,20 @@ MOO
     }
 }
 
-
 print $fh <<FOOTER
 
   /* NOLINTNEXTLINE(clang-analyzer-optin.core.EnumCastOutOfRange) */
   curl_easy_setopt(curl, (CURLoption)1, 0L);
-  res = CURLE_OK;
+  result = CURLE_OK;
 test_cleanup:
   curl_easy_cleanup(curl);
   curl_easy_cleanup(dep);
   curl_share_cleanup(share);
   curl_global_cleanup();
 
-  if(!res)
+  if(!result)
     puts("ok");
-  return res;
+  return result;
 }
 FOOTER
     ;
