@@ -2,14 +2,16 @@
 
 #include "first.h"
 
-#include "memptr.c"
 #include "getpart.c"
 #include "util.c"
 #include "../../lib/curlx/base64.c"
-#include "../../lib/curlx/inet_pton.c"
+#include "../../lib/curlx/fopen.c"
 #include "../../lib/curlx/inet_ntop.c"
+#include "../../lib/curlx/inet_pton.c"
 #include "../../lib/curlx/multibyte.c"
 #include "../../lib/curlx/nonblock.c"
+#include "../../lib/curlx/strcopy.c"
+#include "../../lib/curlx/strerr.c"
 #include "../../lib/curlx/strparse.c"
 #include "../../lib/curlx/timediff.c"
 #include "../../lib/curlx/timeval.c"
@@ -17,6 +19,7 @@
 #include "../../lib/curlx/wait.c"
 #include "../../lib/curlx/warnless.c"
 #include "../../lib/curlx/winapi.c"
+#include "../../src/toolx/tool_time.c"
 #include "dnsd.c"
 #include "mqttd.c"
 #include "resolve.c"
