@@ -36,10 +36,10 @@ static void splayprint(struct Curl_tree *t, int d, char output)
   splayprint(t->larger, d + 1, output);
   for(i = 0; i < d; i++)
     if(output)
-      printf("  ");
+      curl_mprintf("  ");
 
   if(output) {
-    printf("%ld.%ld[%d]", (long)t->key.tv_sec, (long)t->key.tv_usec, i);
+    curl_mprintf("%ld.%ld[%d]", (long)t->key.tv_sec, (long)t->key.tv_usec, i);
   }
 
   for(count = 0, node = t->samen; node != t; node = node->samen, count++)
@@ -47,9 +47,9 @@ static void splayprint(struct Curl_tree *t, int d, char output)
 
   if(output) {
     if(count)
-      printf(" [%d more]\n", count);
+      curl_mprintf(" [%d more]\n", count);
     else
-      printf("\n");
+      curl_mprintf("\n");
   }
 
   splayprint(t->smaller, d + 1, output);
@@ -63,37 +63,37 @@ static CURLcode test_unit1309(const char *arg)
 #define NUM_NODES 50
 
   struct Curl_tree *root, *removed;
-  struct Curl_tree nodes[NUM_NODES*3];
-  size_t storage[NUM_NODES*3];
+  struct Curl_tree nodes[NUM_NODES * 3];
+  size_t storage[NUM_NODES * 3];
   int rc;
   int i, j;
-  struct curltime tv_now = {0, 0};
-  root = NULL;              /* the empty tree */
+  struct curltime tv_now = { 0, 0 };
+  root = NULL; /* the empty tree */
 
   /* add nodes */
   for(i = 0; i < NUM_NODES; i++) {
     struct curltime key;
 
     key.tv_sec = 0;
-    key.tv_usec = (541*i)%1023;
+    key.tv_usec = (541 * i) % 1023;
     storage[i] = key.tv_usec;
     Curl_splayset(&nodes[i], &storage[i]);
-    root = Curl_splayinsert(key, root, &nodes[i]);
+    root = Curl_splayinsert(&key, root, &nodes[i]);
   }
 
   puts("Result:");
   splayprint(root, 0, 1);
 
   for(i = 0; i < NUM_NODES; i++) {
-    int rem = (i + 7)%NUM_NODES;
-    printf("Tree look:\n");
+    int rem = (i + 7) % NUM_NODES;
+    curl_mprintf("Tree look:\n");
     splayprint(root, 0, 1);
     curl_mprintf("remove pointer %d, payload %zu\n", rem,
                  *(size_t *)Curl_splayget(&nodes[rem]));
     rc = Curl_splayremove(root, &nodes[rem], &root);
     if(rc) {
       /* failed! */
-      printf("remove %d failed!\n", rem);
+      curl_mprintf("remove %d failed!\n", rem);
       fail("remove");
     }
   }
@@ -105,26 +105,26 @@ static CURLcode test_unit1309(const char *arg)
     struct curltime key;
 
     key.tv_sec = 0;
-    key.tv_usec = (541*i)%1023;
+    key.tv_usec = (541 * i) % 1023;
 
     /* add some nodes with the same key */
     for(j = 0; j <= i % 3; j++) {
-      storage[i * 3 + j] = key.tv_usec*10 + j;
+      storage[i * 3 + j] = key.tv_usec * 10 + j;
       Curl_splayset(&nodes[i * 3 + j], &storage[i * 3 + j]);
-      root = Curl_splayinsert(key, root, &nodes[i * 3 + j]);
+      root = Curl_splayinsert(&key, root, &nodes[i * 3 + j]);
     }
   }
 
   removed = NULL;
   for(i = 0; i <= 1100; i += 100) {
-    printf("Removing nodes not larger than %d\n", i);
+    curl_mprintf("Removing nodes not larger than %d\n", i);
     tv_now.tv_usec = i;
-    root = Curl_splaygetbest(tv_now, root, &removed);
+    root = Curl_splaygetbest(&tv_now, root, &removed);
     while(removed) {
       curl_mprintf("removed payload %zu[%zu]\n",
                    *(size_t *)Curl_splayget(removed) / 10,
                    *(size_t *)Curl_splayget(removed) % 10);
-      root = Curl_splaygetbest(tv_now, root, &removed);
+      root = Curl_splaygetbest(&tv_now, root, &removed);
     }
   }
 
